from typing import Literal, Required, Union, TypedDict


class CheckResult(TypedDict, total=False):
    """
    check_result.

    A message containing the result of the uptime check.
    """

    guid: Required[str]
    """
    Unique identifier of the uptime check

    Required property
    """

    subscription_id: Required[str]
    """
    Identifier of the subscription that this check was run for

    Required property
    """

    status: Required["CheckStatus"]
    """
    check_status.

    The status of the check

    Required property
    """

    status_reason: Required[Union["CheckStatusReason", None]]
    """
    Aggregation type: oneOf

    Required property
    """

    trace_id: Required[str]
    """
    Trace ID associated with the check-in made

    Required property
    """

    span_id: Required[str]
    """
    Span ID associated with the check-in made. This is a phantom span generated by the uptime-checker, no real span is ingested.

    Required property
    """

    scheduled_check_time_ms: Required[Union[int, float]]
    """
    Timestamp in milliseconds of when the check was schedule to run

    Required property
    """

    actual_check_time_ms: Required[Union[int, float]]
    """
    Timestamp in milliseconds of when the check was actually ran

    Required property
    """

    duration_ms: Required[Union[Union[int, float], None]]
    """
    Duration of the check in ms. Will be null when the status is missed_window

    Required property
    """

    request_info: Required[Union["RequestInfo", None]]
    """
    Aggregation type: oneOf

    Required property
    """

    region: str
    """ The region that this check was performed in """



CheckStatus = Union[Literal['success'], Literal['failure'], Literal['missed_window']]
"""
check_status.

The status of the check
"""
CHECKSTATUS_SUCCESS: Literal['success'] = "success"
"""The values for the 'check_status' enum"""
CHECKSTATUS_FAILURE: Literal['failure'] = "failure"
"""The values for the 'check_status' enum"""
CHECKSTATUS_MISSED_WINDOW: Literal['missed_window'] = "missed_window"
"""The values for the 'check_status' enum"""



class CheckStatusReason(TypedDict, total=False):
    """
    check_status_reason.

    Reason for the status, primairly used for failure
    """

    type: Required["CheckStatusReasonType"]
    """
    check_status_reason_type.

    The type of the status reason

    Required property
    """

    description: Required[str]
    """
    A human readable description of the status reason

    Required property
    """



CheckStatusReasonType = Union[Literal['timeout'], Literal['dns_error'], Literal['failure'], Literal['tls_error'], Literal['connection_error'], Literal['redirect_error']]
"""
check_status_reason_type.

The type of the status reason
"""
CHECKSTATUSREASONTYPE_TIMEOUT: Literal['timeout'] = "timeout"
"""The values for the 'check_status_reason_type' enum"""
CHECKSTATUSREASONTYPE_DNS_ERROR: Literal['dns_error'] = "dns_error"
"""The values for the 'check_status_reason_type' enum"""
CHECKSTATUSREASONTYPE_FAILURE: Literal['failure'] = "failure"
"""The values for the 'check_status_reason_type' enum"""
CHECKSTATUSREASONTYPE_TLS_ERROR: Literal['tls_error'] = "tls_error"
"""The values for the 'check_status_reason_type' enum"""
CHECKSTATUSREASONTYPE_CONNECTION_ERROR: Literal['connection_error'] = "connection_error"
"""The values for the 'check_status_reason_type' enum"""
CHECKSTATUSREASONTYPE_REDIRECT_ERROR: Literal['redirect_error'] = "redirect_error"
"""The values for the 'check_status_reason_type' enum"""



class RequestInfo(TypedDict, total=False):
    """
    request_info.

    Additional information about the request made
    """

    request_type: Required["RequestType"]
    """
    request_type.

    The type of HTTP method used for the check

    Required property
    """

    http_status_code: Required[Union[Union[int, float], None]]
    """
    Status code of the successful check-in

    Required property
    """



RequestType = Union[Literal['GET'], Literal['POST'], Literal['HEAD'], Literal['PUT'], Literal['DELETE'], Literal['PATCH'], Literal['OPTIONS']]
"""
request_type.

The type of HTTP method used for the check
"""
REQUESTTYPE_GET: Literal['GET'] = "GET"
"""The values for the 'request_type' enum"""
REQUESTTYPE_POST: Literal['POST'] = "POST"
"""The values for the 'request_type' enum"""
REQUESTTYPE_HEAD: Literal['HEAD'] = "HEAD"
"""The values for the 'request_type' enum"""
REQUESTTYPE_PUT: Literal['PUT'] = "PUT"
"""The values for the 'request_type' enum"""
REQUESTTYPE_DELETE: Literal['DELETE'] = "DELETE"
"""The values for the 'request_type' enum"""
REQUESTTYPE_PATCH: Literal['PATCH'] = "PATCH"
"""The values for the 'request_type' enum"""
REQUESTTYPE_OPTIONS: Literal['OPTIONS'] = "OPTIONS"
"""The values for the 'request_type' enum"""



class SnubaUptimeResult(TypedDict, total=False):
    """ snuba_uptime_result. """

    organization_id: Required[int]
    """
    The organization ID associated with this check

    minimum: 0

    Required property
    """

    project_id: Required[int]
    """
    The project ID associated with this check

    minimum: 0

    Required property
    """

    retention_days: Required[int]
    """
    Number of days to retain this data

    minimum: 0
    maximum: 65535

    Required property
    """

    environment: str
    """ The environment associated with this check """

    incident_status: int
    """
    Indicates this results is part of a detected incident

    minimum: 0
    maximum: 1
    """

    guid: Required[str]
    """
    Unique identifier of the uptime check

    Required property
    """

    subscription_id: Required[str]
    """
    Identifier of the subscription that this check was run for

    Required property
    """

    status: Required["CheckStatus"]
    """
    check_status.

    The status of the check

    Required property
    """

    status_reason: Required[Union["CheckStatusReason", None]]
    """
    Aggregation type: oneOf

    Required property
    """

    trace_id: Required[str]
    """
    Trace ID associated with the check-in made

    Required property
    """

    span_id: Required[str]
    """
    Span ID associated with the check-in made. This is a phantom span generated by the uptime-checker, no real span is ingested.

    Required property
    """

    scheduled_check_time_ms: Required[Union[int, float]]
    """
    Timestamp in milliseconds of when the check was schedule to run

    Required property
    """

    actual_check_time_ms: Required[Union[int, float]]
    """
    Timestamp in milliseconds of when the check was actually ran

    Required property
    """

    duration_ms: Required[Union[Union[int, float], None]]
    """
    Duration of the check in ms. Will be null when the status is missed_window

    Required property
    """

    request_info: Required[Union["RequestInfo", None]]
    """
    Aggregation type: oneOf

    Required property
    """

    region: str
    """ The region that this check was performed in """

